"""Filesystem monomers — stubs."""

_STUB = "Extended monomer stub"


def fs_stat(path: str) -> dict[str, int]:
    raise NotImplementedError(_STUB)


def fs_mkdir(path: str) -> None:
    raise NotImplementedError(_STUB)


def fs_rmdir(path: str) -> None:
    raise NotImplementedError(_STUB)


def fs_list(path: str) -> list[str]:
    raise NotImplementedError(_STUB)


def fs_rename(src: str, dst: str) -> None:
    raise NotImplementedError(_STUB)


def fs_remove(path: str) -> None:
    raise NotImplementedError(_STUB)


def fs_exists(path: str) -> bool:
    raise NotImplementedError(_STUB)


def fs_copy(src: str, dst: str) -> None:
    raise NotImplementedError(_STUB)
