"""Graphics monomers — stubs."""

_STUB = "Extended monomer stub"


def fb_create(width: int, height: int) -> int:
    raise NotImplementedError(_STUB)


def fb_pixel(fb: int, x: int, y: int, color: int) -> None:
    raise NotImplementedError(_STUB)


def fb_line(fb: int, x0: int, y0: int, x1: int, y1: int, color: int) -> None:
    raise NotImplementedError(_STUB)


def fb_rect(fb: int, x: int, y: int, w: int, h: int, color: int) -> None:
    raise NotImplementedError(_STUB)


def fb_clear(fb: int, color: int) -> None:
    raise NotImplementedError(_STUB)


def fb_blit(fb: int) -> None:
    raise NotImplementedError(_STUB)


def fb_read(fb: int, x: int, y: int) -> int:
    raise NotImplementedError(_STUB)


def fb_dims(fb: int) -> tuple[int, int]:
    raise NotImplementedError(_STUB)
