"""Audio monomers — stubs."""

_STUB = "Extended monomer stub"


def aud_create(sample_rate: int, channels: int) -> int:
    raise NotImplementedError(_STUB)


def aud_play(buf: int) -> None:
    raise NotImplementedError(_STUB)


def aud_stop(buf: int) -> None:
    raise NotImplementedError(_STUB)


def aud_write(buf: int, data: bytes) -> int:
    raise NotImplementedError(_STUB)


def aud_read(buf: int, size: int) -> bytes:
    raise NotImplementedError(_STUB)


def aud_volume(buf: int, level: float) -> None:
    raise NotImplementedError(_STUB)


def aud_rate(buf: int) -> int:
    raise NotImplementedError(_STUB)


def aud_chans(buf: int) -> int:
    raise NotImplementedError(_STUB)
