"""I/O monomers — stubs."""

_STUB = "Extended monomer stub"


def read(fd: int, size: int) -> bytes:
    raise NotImplementedError(_STUB)


def write(fd: int, data: bytes) -> int:
    raise NotImplementedError(_STUB)


def open_file(path: str, mode: str = "r") -> int:
    raise NotImplementedError(_STUB)


def close_file(fd: int) -> None:
    raise NotImplementedError(_STUB)


def seek(fd: int, offset: int) -> None:
    raise NotImplementedError(_STUB)


def flush(fd: int) -> None:
    raise NotImplementedError(_STUB)


def eof(fd: int) -> bool:
    raise NotImplementedError(_STUB)


def err(fd: int) -> bool:
    raise NotImplementedError(_STUB)
