"""Network monomers — stubs."""

_STUB = "Extended monomer stub"


def tcp_conn(host: str, port: int) -> int:
    raise NotImplementedError(_STUB)


def tcp_send(fd: int, data: bytes) -> int:
    raise NotImplementedError(_STUB)


def tcp_recv(fd: int, size: int) -> bytes:
    raise NotImplementedError(_STUB)


def tcp_close(fd: int) -> None:
    raise NotImplementedError(_STUB)


def udp_send(host: str, port: int, data: bytes) -> int:
    raise NotImplementedError(_STUB)


def udp_recv(fd: int, size: int) -> bytes:
    raise NotImplementedError(_STUB)


def dns_resolve(hostname: str) -> str:
    raise NotImplementedError(_STUB)


def http_req(url: str, method: str = "GET") -> str:
    raise NotImplementedError(_STUB)
