"""System monomers — time_unix, pid, env_get real, rest stubs."""

import os
import time

_STUB = "Extended monomer stub"


def time_unix() -> int:
    return int(time.time())


def cpu() -> float:
    raise NotImplementedError(_STUB)


def disk() -> dict[str, int]:
    raise NotImplementedError(_STUB)


def net() -> dict[str, int]:
    raise NotImplementedError(_STUB)


def env_get(key: str, default: str | None = None) -> str | None:
    return os.environ.get(key, default)


def pid() -> int:
    return os.getpid()


def thread() -> int:
    raise NotImplementedError(_STUB)


def exec_cmd(cmd: str) -> str:
    raise NotImplementedError(_STUB)
