"""Memory monomers — stubs."""

_STUB = "Extended monomer stub"


def load(addr: int) -> int:
    raise NotImplementedError(_STUB)


def store(addr: int, val: int) -> None:
    raise NotImplementedError(_STUB)


def push(val: int) -> None:
    raise NotImplementedError(_STUB)


def pop() -> int:
    raise NotImplementedError(_STUB)


def peek() -> int:
    raise NotImplementedError(_STUB)


def dup() -> None:
    raise NotImplementedError(_STUB)


def drop() -> None:
    raise NotImplementedError(_STUB)


def swap() -> None:
    raise NotImplementedError(_STUB)
