"""Math monomers — real math.* wrappers."""

import math


def sin(x: float) -> float:
    return math.sin(x)


def cos(x: float) -> float:
    return math.cos(x)


def tan(x: float) -> float:
    return math.tan(x)


def exp(x: float) -> float:
    return math.exp(x)


def ln(x: float) -> float:
    return math.log(x)


def log2(x: float) -> float:
    return math.log2(x)


def pow_op(base: float, exponent: float) -> float:
    return math.pow(base, exponent)


def ceil(x: float) -> int:
    return math.ceil(x)
