"""Concurrency monomers — stubs."""

from typing import Any

_STUB = "Extended monomer stub"


def spawn(fn: Any) -> int:
    raise NotImplementedError(_STUB)


def join(tid: int) -> Any:
    raise NotImplementedError(_STUB)


def chan_new() -> int:
    raise NotImplementedError(_STUB)


def chan_send(ch: int, val: Any) -> None:
    raise NotImplementedError(_STUB)


def chan_recv(ch: int) -> Any:
    raise NotImplementedError(_STUB)


def mutex_new() -> int:
    raise NotImplementedError(_STUB)


def mutex_lock(m: int) -> None:
    raise NotImplementedError(_STUB)


def mutex_unlock(m: int) -> None:
    raise NotImplementedError(_STUB)
