"""Control monomers — stubs."""

from typing import Any, Callable

_STUB = "Extended monomer stub"


def if_then(cond: bool, then_fn: Callable[[], Any]) -> Any | None:
    raise NotImplementedError(_STUB)


def loop_n(n: int, body: Callable[[int], Any]) -> None:
    raise NotImplementedError(_STUB)


def call(fn: Callable[..., Any], *args: Any) -> Any:
    raise NotImplementedError(_STUB)


def ret(val: Any) -> Any:
    raise NotImplementedError(_STUB)


def break_op() -> None:
    raise NotImplementedError(_STUB)


def continue_op() -> None:
    raise NotImplementedError(_STUB)


def nop() -> None:
    raise NotImplementedError(_STUB)


def exit_op(code: int = 0) -> None:
    raise NotImplementedError(_STUB)
